<?php 

$lang['module_name'] = 'Cache module';

$lang['display_as'] = array(
    'name' => 'Page',
    'cache' => 'To cache'
);

$lang['Activate cache'] = 'Enable';
$lang['Activate cache?'] = 'Enable cache for page(s)?';
$lang['Deactivate cache'] = 'Disable';
$lang['Deactivate cache?'] = 'Disable cache for page(s)?';
$lang['Clear cache'] = 'Clear cache';
$lang['Clear cache?'] = 'Clear cache for page(s)?';